@@ -2,6 +2,8 @@ from pydantic import BaseSettings
 
 
 class Settings(BaseSettings):
+    ENVIRONMENT: str = 'dev'
+
     AWS_REGION: str = 'ap-southeast-1'
     AWS_SNS_KEY: str = None
     AWS_SNS_SECRET: str = None
@@ -11,6 +13,8 @@ class Settings(BaseSettings):
         case_sensitive = True
 
         fields = {
+            'ENVIRONMENT': {'env': 'ENVIRONMENT'},
+
             'AWS_REGION': {'env': 'AWS_REGION'},
             'AWS_SNS_KEY': {'env': 'AWS_SNS_KEY'},
             'AWS_SNS__SECRET': {'env': 'AWS_SNS__SECRET'},
